<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class AgendamentoRecursosFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getAgendamentoRecursoCont()
    {
        $sql = "SELECT
                    AGEN.NRAGENDRECURSOCONT,
                    AGEN.NRSEQCONTRATO,
                    TO_CHAR(AGEN.DTINIAGENDAMENTO, 'DD/MM/YYYY') AS DTINIAGENDAMENTO,
                    TO_CHAR(AGEN.DTFIMAGENDAMENTO, 'DD/MM/YYYY') AS DTFIMAGENDAMENTO,
                    CONT.NRPARCNEGOCIO,
                    PARC.NMSECUNDARIPARC,
                    CONT.NRCONTRATOFCT,
                    CONT.DSREFERENCIACONT,
                    AGEN.NRESTRUTURAM,
                    LOCAL.NMESTRUTURAM,
                    AGEN.QTTOLERANCIARAIO,
                    AGEN.NRORG,
                    AGEN.IDATIVO,
                    AGEN.DTINCLUSAO,
                    AGEN.NRORGINCLUSAO,
                    AGEN.CDOPERINCLUSAO,
                    AGEN.DTULTATU,
                    AGEN.NRORGULTATU,
                    AGEN.CDOPERULTATU
                FROM
                    FCT_AGENDRECURSOCONT AGEN
                    LEFT JOIN FCT_CONTRATO         CONT ON AGEN.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                    LEFT JOIN PARCNEGOCIO          PARC ON PARC.NRPARCNEGOCIO = CONT.NRPARCNEGOCIO
                    LEFT JOIN ESTRUTURAM           LOCAL ON AGEN.NRESTRUTURAM = LOCAL.NRESTRUTURAM
                ORDER BY DTINIAGENDAMENTO DESC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertAgendamentoRecursoCont(array $params) {
        $sql = "INSERT INTO FCT_AGENDRECURSOCONT (NRAGENDRECURSOCONT, NRSEQCONTRATO, NRESTRUTURAM, DTINIAGENDAMENTO, DTFIMAGENDAMENTO, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                            VALUES (:NRAGENDRECURSOCONT, :NRSEQCONTRATO, :NRESTRUTURAM, :DTINIAGENDAMENTO, :DTFIMAGENDAMENTO, :NRORG, :IDATIVO, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO)";
                             
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function updateAgendamentoRecursoCont($parametros)
    {
        $sql = "UPDATE FCT_AGENDRECURSOCONT
                SET NRSEQCONTRATO = :NRSEQCONTRATO,
                    NRESTRUTURAM = :NRESTRUTURAM,
                    DTINIAGENDAMENTO = :DTINIAGENDAMENTO,
                    DTFIMAGENDAMENTO = :DTFIMAGENDAMENTO,
                    DTULTATU = SYSDATE,
                    NRORG = :NRORG,
                    IDATIVO = :IDATIVO,
                    NRORGULTATU = :NRORGULTATU,
                    CDOPERULTATU = :CDOPERULTATU
                WHERE NRAGENDRECURSOCONT = :NRAGENDRECURSOCONT";
        
        $this->connection->executeStatement($sql, $parametros);
    }

    public function deleteAgendRecursos($parametros)
    {
        $sql = "DELETE FROM FCT_AGENDRECURSOCONT WHERE NRAGENDRECURSOCONT IN ($parametros)";

        $this->connection->executeStatement($sql);
    }

    public function getContratosAgendRecurso()
    {
        $sql = "SELECT
                    NRSEQCONTRATO,
                    NRCONTRATOFCT,
                    DSREFERENCIACONT,
                    NRCONTRATOFCT || ' | ' || DSREFERENCIACONT AS DESCRICACAOCONTRATO
                FROM
                    FCT_CONTRATO
                WHERE
                    IDATIVO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getRelacEstruturaCont($param)
    {
        $sql = "SELECT DISTINCT
                    REL.NRESTRUTURAM,
                    EST.NMESTRUTURAM,
                    REL.NRORG
                FROM
                        FCT_RELACESTRUTURACONT REL
                    JOIN ESTRUTURAM EST ON REL.NRESTRUTURAM = EST.NRESTRUTURAM
                WHERE
                    ( ( REL.NRSEQCONTRATO = :NRSEQCONTRATO )
                    OR ( :NRSEQCONTRATO IS NULL ) )";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $param);
    }
    
    public function getRecursosAgendCont($params)
    {

                $sql = "SELECT
                            RECU.NRRECURSOSAGENDCONT,
                            RECU.NRAGENDRECURSOCONT,
                            RECU.NRITEMOCONTRATO,
                            ITEM.NMITEMCONTRATO,
                        FROM
                            FCT_RECURSOSAGENDCONT RECU
                            LEFT JOIN FCT_ITEMCONTRATO      ITEM ON RECU.NRITEMOCONTRATO = ITEM.NRITEMOCONTRATO
                        WHERE RECU.NRAGENDRECURSOCONT = :NRAGENDRECURSOCONT";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    } 

    public function getItemContAgendRecurso($param)
    {
        $sql = "SELECT
                    ITEM.NRITEMOCONTRATO,
                    ITEM.NRSEQCONTRATO,
                    ITEM.NMITEMCONTRATO,
                    SERV.IDSERVAGENDADO,
                    CONT.NRCONTRATOFCT
                FROM
                        FCT_ITEMCONTRATO ITEM
                    INNER JOIN FCT_CONTRATO    CONT ON ITEM.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                    LEFT JOIN FCT_SERVICOORCA SERV ON ITEM.CDSERVORCA = SERV.CDSERVORCA
                WHERE
                        ITEM.NRSEQCONTRATO = :NRSEQCONTRATO
                    -- AND SERV.IDSERVAGENDADO = 'S'
                ";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $param);
    }

    public function getRecursoAgendCont($param)
    {
        $sql = "SELECT
                    RECU.NRRECURSOSAGENDCONT,
                    RECU.NRAGENDRECURSOCONT,
                    ITEM.NRITEMOCONTRATO,
                    TO_CHAR(RECU.DTINIAGENDRECURSO, 'DD/MM/YYYY') AS DTINIAGENDRECURSO,
                    TO_CHAR(RECU.DTFIMAGENDRECURSO, 'DD/MM/YYYY') AS DTFIMAGENDRECURSO,
                    FCT_VIEW_RECURSOS.NMRECURSO,
                    FCT_VIEW_RECURSOS.CODRECURSO,
                    FCT_VIEW_RECURSOS.NMTIPO,
                    CONT.NRCONTRATOFCT,
                    CONT.NRSEQCONTRATO,
                    ITEM.NMITEMCONTRATO,
                    RECU.IDREPETDOMINGO,
                    RECU.IDREPETSEGUNDA,
                    RECU.IDREPETTERCA,
                    RECU.IDREPETQUARTA,
                    RECU.IDREPETQUINTA,
                    RECU.IDREPETSEXTA,
                    RECU.IDREPETSABADO,
                    RECU.IDMOTIVOAGENDAMENTO,
                    RECU.IDSITUARECGEND,
                    RECU.HRPRIMEIRAENTRADA,
                    RECU.HRPRIMEIRASAIDA,
                    RECU.HRSEGUNDAENTRADA,
                    RECU.HRSEGUNDASAIDA,
                    RECU.NRTEMPOTOLERANCIA,
                    RECU.IDHORAEXTRA,
                    RECU.IDDESCANSOREMU,
                    RECU.IDESCALATRAB,
                    RECU.HRJORNADADIARIA,
                    RECU.HRINTERVALO,
                    RECU.HRDESCANSO,
                    RECU.IDALTERACAOEQUIPE,
                    RECU.DTULTATU,
                    RECU.NRRECURSOALTEQUIPE,
                    RECU.DSJUSTIFICAALTEQUIPE
                FROM
                    FCT_RECURSOSAGENDCONT RECU
                    LEFT JOIN FCT_VIEW_RECURSOS ON NVL(TO_CHAR(RECU.NRPARCNEPESSOA),
                                                        NVL(RECU.CDBEMATIVO, RECU.CDPRODUTO)) = FCT_VIEW_RECURSOS.CHAVE
                                                AND RECU.IDTPRECURSO = FCT_VIEW_RECURSOS.CDTIPO
                                                AND NVL(RECU.CDEMPRESA, - 1) = NVL(FCT_VIEW_RECURSOS.CDEMPRESA, - 1)
                    LEFT JOIN FCT_ITEMCONTRATO ITEM ON RECU.NRITEMOCONTRATO = ITEM.NRITEMOCONTRATO
                    INNER JOIN FCT_CONTRATO CONT ON ITEM.NRSEQCONTRATO = CONT.NRSEQCONTRATO                                     
                WHERE
                    RECU.NRITEMOCONTRATO = :NRITEMOCONTRATO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $param);
    }
}