<?php

namespace SM\Service;

use SM\Factory\Sm00005000TabParametrizacoesEmailFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00005000TabParametrizacoesEmailService
{
    protected $connection;
    protected $parametrizacaoEmailFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00005000TabParametrizacoesEmailFactory $parametrizacaoEmailFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->parametrizacaoEmailFactory   = $parametrizacaoEmailFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getParametrosEmailFilial()
    {
        return $this->parametrizacaoEmailFactory->getParametrosEmailFilial();
    }
    
    public function saveParameterEmail($parametros)
    {
        try {
            $this->connection->beginTransaction();
            $nrorg = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            $escopos = null;

            $paramsValidaFilial = array(
                "NRPARAMEMAILFILIAL" => $parametros['NRPARAMEMAILFILIAL'],
                "CDFILIAL"           => $parametros['CDFILIAL'],
            );

            $valor = $this->parametrizacaoEmailFactory->validaRegistrosDuplicados($paramsValidaFilial);

            if ($valor[0]["QTD"] > 0) {
                throw new \Exception("EXISTE");
            }

            if ($parametros["NRTIPOORCAMENTO"] != null) {
                $arrayEscopos = $parametros["NRTIPOORCAMENTO"];
                sort($arrayEscopos);
                $escopos = isset($arrayEscopos)? implode("_", $arrayEscopos): null;
            }

            $paramsValidaEscopos = array(
                "NRPARAMEMAILFILIAL" => $parametros['NRPARAMEMAILFILIAL'],
                "CDFILIAL"           => $parametros['CDFILIAL'],
                "NRTIPOORCAMENTO"    => $escopos,
            );

            $validaEscopos = $this->parametrizacaoEmailFactory->validaRegistrosComEscopoDuplicados($paramsValidaEscopos);

            if ($validaEscopos[0]["QTD"] > 0) {
                throw new \Exception("CONTEM_ESCOPO");
            }

            if ($parametros["NRPARAMEMAILFILIAL"] == null) {
                $nrparamemailfilial = $this->newCode->getCodeByTableName("FCT_PARAMEMAILFILIAL", $nrorg, 1, 10, true);
                $inserindo = true;
            } else {
                $nrparamemailfilial = $parametros["NRPARAMEMAILFILIAL"];
                $inserindo = false;
            }

            $dataParams = array (
                "NRPARAMEMAILFILIAL"        => $nrparamemailfilial,
                "DSPARAMEMAILFILIAL"        => $parametros["DSPARAMEMAILFILIAL"],
                "CDFILIAL"                  => $parametros["CDFILIAL"],
                "DSREMETENTEEMAIL"          => $parametros["DSREMETENTEEMAIL"],
                "DSASSUNTOEMAIL"            => $parametros["DSASSUNTOEMAIL"],
                "DSCORPOEMAIL"              => $parametros["DSCORPOEMAIL"],
                "NRTIPOORCAMENTO"           => $escopos,
                "NRORG"                     => $nrorg,
                "NRORGINCLUSAO"             => $nrorg,
                "NRORGULTATU"               => $nrorg,
                "CDOPERINCLUSAO"            => $cdoperador,
                "CDOPERULTATU"              => $cdoperador,
                "IDATIVO"                   => "S",
                "IS_NEW"                    => $inserindo
            );

            if ($inserindo === true) {
                unset($dataParams['NRORGULTATU'], $dataParams['CDOPERULTATU']);
                $this->parametrizacaoEmailFactory->insertParameterEmail($dataParams);
            } else {
                unset($dataParams['NRORGINCLUSAO'], $dataParams['CDOPERINCLUSAO']);
                $this->parametrizacaoEmailFactory->updateParameterEmail($dataParams);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteParametrosEmail($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $parametroEmail) {
                $dataParam = array( "NRPARAMEMAILFILIAL" => $parametroEmail["NRPARAMEMAILFILIAL"],);
                $this->parametrizacaoEmailFactory->deleteParametrosEmail($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
